@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_configuration.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -311,11 +311,13 @@ class TrackMeHandlerConfigurationRead_v2(trackme_rest_handler.RESTHandler):
         ui_defaults_conf = trackmeconf.get("trackme_ui_defaults", {})
         ui_default_theme = ui_defaults_conf.get("default_theme", "dark")
         ui_auto_refresh = ui_defaults_conf.get("auto_refresh", "1")
+        ui_vtenants_card_detail_level = ui_defaults_conf.get("vtenants_card_detail_level", "0")
 
         # Add ui_default_theme to response (system-level setting)
         user_prefs_dict = {
             "ui_default_theme": ui_default_theme,
             "ui_auto_refresh": ui_auto_refresh,
+            "ui_vtenants_card_detail_level": ui_vtenants_card_detail_level,
         }
 
         # add user_prefs_dict to response
