@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_dhm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -555,19 +555,6 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                         "status": 500,
                     }
 
-                try:
-                    data_lag_alert_kpis = resp_dict[
-                        "data_lag_alert_kpis"
-                    ]  # all_kpis / lag_ingestion_kpi / lag_event_kpi
-                    if not data_lag_alert_kpis in (
-                        "all_kpis",
-                        "lag_ingestion_kpi",
-                        "lag_event_kpi",
-                    ):
-                        data_lag_alert_kpis = None
-                except Exception as e:
-                    data_lag_alert_kpis = None
-
                 try:
                     data_max_lag_allowed = resp_dict["data_max_lag_allowed"]
                     data_max_lag_allowed = convert_time_to_seconds(data_max_lag_allowed)
@@ -618,6 +605,35 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                 except Exception as e:
                     future_tolerance = None
 
+                try:
+                    impact_score_weights = resp_dict.get("impact_score_weights")
+                    if impact_score_weights:
+                        # Validate it's a dict or can be parsed as JSON
+                        if isinstance(impact_score_weights, str):
+                            impact_score_weights = json.loads(impact_score_weights)
+                        if isinstance(impact_score_weights, dict):
+                            # Validate keys are 'delay' and/or 'latency' with integer values 0-100
+                            validated_weights = {}
+                            for key in ["delay", "latency"]:
+                                if key in impact_score_weights:
+                                    try:
+                                        weight_value = int(impact_score_weights[key])
+                                        if 0 <= weight_value <= 100:
+                                            validated_weights[key] = weight_value
+                                    except (ValueError, TypeError):
+                                        pass
+                            # Only set if we have at least one valid weight
+                            if validated_weights:
+                                impact_score_weights = json.dumps(validated_weights)
+                            else:
+                                impact_score_weights = None
+                        else:
+                            impact_score_weights = None
+                    else:
+                        impact_score_weights = None
+                except (json.JSONDecodeError, TypeError, ValueError) as e:
+                    impact_score_weights = None
+
         else:
             # body is required in this endpoint, if not submitted describe the usage
             describe = True
@@ -626,19 +642,19 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             response = {
                 "describe": "This endpoint resets (removal of index and sourcetype knowledge) an existing data host by the data host name (object), it requires a POST call with the following information:",
                 "resource_desc": "Update lag policies for a comma separated list of entities",
-                "resource_spl_example": "| trackme url=\"/services/trackme/v2/splk_dhm/write/dh_update_lag_policy\" mode=\"post\" body=\"{'tenant_id':'mytenant','object_list':'remote|account:lab|firewall.pan.amer.design.node1','data_max_lag_allowed':'900','data_max_delay_allowed':'1600','data_lag_alert_kpis':'all_kpis','data_override_lagging_class':'false','splk_dhm_alerting_policy': 'global'}\"",
+                "resource_spl_example": "| trackme url=\"/services/trackme/v2/splk_dhm/write/dh_update_lag_policy\" mode=\"post\" body=\"{'tenant_id':'mytenant','object_list':'remote|account:lab|firewall.pan.amer.design.node1','data_max_lag_allowed':'900','data_max_delay_allowed':'1600','data_override_lagging_class':'false','splk_dhm_alerting_policy': 'global'}\"",
                 "options": [
                     {
                         "tenant_id": "The tenant identifier",
                         "object_list": "List of object entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
                         "keys_list": "List of key entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
-                        "data_lag_alert_kpis": "OPTIONAL, KPIs policy to be applied, valid options are all_kpis / lag_ingestion_kpi / lag_event_kpi",
-                        "data_max_lag_allowed": "OPTIONAL, maximal accepted lagging value in seconds or with unit suffix (h/d/w), e.g. 3600 or '1h' or '1d' or '1w'",
-                        "data_max_delay_allowed": "OPTIONAL, maximal accepted delay value in seconds or with unit suffix (h/d/w), e.g. 3600 or '1h' or '1d' or '1w'",
+                        "data_max_lag_allowed": "OPTIONAL, maximal accepted lagging value in seconds or with unit suffix (m/h/d/w), e.g. 3600 or '15m' or '1h' or '1d' or '1w'",
+                        "data_max_delay_allowed": "OPTIONAL, maximal accepted delay value in seconds or with unit suffix (m/h/d/w), e.g. 3600 or '15m' or '1h' or '1d' or '1w'",
                         "data_override_lagging_class": "OPTIONAL, overrides lagging classes, valid options are true / false",
                         "splk_dhm_alerting_policy": "OPTIONAL, the policy, valid options are: global_policy / track_per_sourcetype / track_per_host",
                         "future_tolerance": "OPTIONAL, the negative value for future tolerance, specify system to rely on the system level setting, disabled to allow data in the future up to 7 days without affecting the status of the entity",
                         "allow_adaptive_delay": "OPTIONAL, allow adaptive delay, valid options are true / false",
+                        "impact_score_weights": "OPTIONAL, JSON object with custom impact score weights for delay and/or latency (0-100), e.g. {'delay': 100, 'latency': 48}. If not set, tenant-level defaults are used.",
                         "update_comment": "OPTIONAL: a comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
                 ],
@@ -688,8 +704,6 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             update_fields["data_max_lag_allowed"] = data_max_lag_allowed
         if data_max_delay_allowed:
             update_fields["data_max_delay_allowed"] = data_max_delay_allowed
-        if data_lag_alert_kpis:
-            update_fields["data_lag_alert_kpis"] = data_lag_alert_kpis
         if data_override_lagging_class:
             update_fields["data_override_lagging_class"] = data_override_lagging_class
         if splk_dhm_alerting_policy:
@@ -698,6 +712,8 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
             update_fields["allow_adaptive_delay"] = allow_adaptive_delay
         if future_tolerance:
             update_fields["future_tolerance"] = future_tolerance
+        if impact_score_weights:
+            update_fields["impact_score_weights"] = impact_score_weights
         if not update_fields:
             return {
                 "payload": {"error": "no valid fields to update"},
