@@ -3,7 +3,7 @@
 
 __name__ = "trackme_rest_handler_splk_dhm.py"
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -69,6 +69,7 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
     def post_outliers_get_rules(self, request_info, **kwargs):
 
         describe = False
+        object_id_value = None  # Initialize at function scope
 
         # Retrieve from data
         try:
@@ -93,12 +94,22 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 500,
                     }
-                try:
-                    object_value = resp_dict["object"]
-                except Exception as e:
+                
+                # Support both object and object_id, prefer object_id if both provided
+                object_value = None
+                object_id_value = resp_dict.get("object_id")
+                object_param = resp_dict.get("object")
+                
+                if object_id_value:
+                    # object_id provided - will look up object value later
+                    object_value = None  # Will be resolved after service connection
+                elif object_param:
+                    # object provided
+                    object_value = object_param
+                else:
                     return {
                         "payload": {
-                            "response": "object is required",
+                            "response": "object or object_id is required",
                         },
                         "status": 500,
                     }
@@ -164,6 +175,48 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
             logger.error(json.dumps(response))
             return {"payload": response, "status": 500}
 
+        # If object_id was provided, look up the object value from KV store
+        if object_id_value and not object_value:
+            try:
+                # Try to get object from rules collection first (both collections should have the same object)
+                collection_rules_name = (
+                    f"kv_trackme_{component}_outliers_entity_rules_tenant_{tenant_id}"
+                )
+                collection_rule = service.kvstore[collection_rules_name]
+                
+                # Query by _key (object_id)
+                query_string = {"_key": object_id_value}
+                records = collection_rule.data.query(query=json.dumps(query_string))
+                
+                # Try rules collection first
+                if records and len(records) > 0:
+                    object_value = records[0].get("object")
+                
+                # If not found in rules collection, try data collection as fallback
+                if not object_value:
+                    collection_data_name = (
+                        f"kv_trackme_{component}_outliers_entity_data_tenant_{tenant_id}"
+                    )
+                    collection_data = service.kvstore[collection_data_name]
+                    records_data = collection_data.data.query(query=json.dumps(query_string))
+                    if records_data and len(records_data) > 0:
+                        object_value = records_data[0].get("object")
+                
+                if not object_value:
+                    return {
+                        "payload": {
+                            "response": f'object_id="{object_id_value}" not found in KV store',
+                        },
+                        "status": 500,
+                    }
+            except Exception as e:
+                response = {
+                    "action": "failure",
+                    "response": f'Failed to look up object from object_id, exception="{str(e)}"',
+                }
+                logger.error(json.dumps(response))
+                return {"payload": response, "status": 500}
+
         # Call helper function directly instead of using Splunk search
         try:
             query_results = get_outliers_rules(
@@ -183,6 +236,7 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
     def post_outliers_get_data(self, request_info, **kwargs):
 
         describe = False
+        object_id_value = None  # Initialize at function scope
 
         # Retrieve from data
         try:
@@ -207,12 +261,22 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 500,
                     }
-                try:
-                    object_value = resp_dict["object"]
-                except Exception as e:
+                
+                # Support both object and object_id, prefer object_id if both provided
+                object_value = None
+                object_id_value = resp_dict.get("object_id")
+                object_param = resp_dict.get("object")
+                
+                if object_id_value:
+                    # object_id provided - will look up object value later
+                    object_value = None  # Will be resolved after service connection
+                elif object_param:
+                    # object provided
+                    object_value = object_param
+                else:
                     return {
                         "payload": {
-                            "response": "object is required",
+                            "response": "object or object_id is required",
                         },
                         "status": 500,
                     }
@@ -278,6 +342,48 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
             logger.error(json.dumps(response))
             return {"payload": response, "status": 500}
 
+        # If object_id was provided, look up the object value from KV store
+        if object_id_value and not object_value:
+            try:
+                # Try to get object from rules collection first (both collections should have the same object)
+                collection_rules_name = (
+                    f"kv_trackme_{component}_outliers_entity_rules_tenant_{tenant_id}"
+                )
+                collection_rule = service.kvstore[collection_rules_name]
+                
+                # Query by _key (object_id)
+                query_string = {"_key": object_id_value}
+                records = collection_rule.data.query(query=json.dumps(query_string))
+                
+                # Try rules collection first
+                if records and len(records) > 0:
+                    object_value = records[0].get("object")
+                
+                # If not found in rules collection, try data collection as fallback
+                if not object_value:
+                    collection_data_name = (
+                        f"kv_trackme_{component}_outliers_entity_data_tenant_{tenant_id}"
+                    )
+                    collection_data = service.kvstore[collection_data_name]
+                    records_data = collection_data.data.query(query=json.dumps(query_string))
+                    if records_data and len(records_data) > 0:
+                        object_value = records_data[0].get("object")
+                
+                if not object_value:
+                    return {
+                        "payload": {
+                            "response": f'object_id="{object_id_value}" not found in KV store',
+                        },
+                        "status": 500,
+                    }
+            except Exception as e:
+                response = {
+                    "action": "failure",
+                    "response": f'Failed to look up object from object_id, exception="{str(e)}"',
+                }
+                logger.error(json.dumps(response))
+                return {"payload": response, "status": 500}
+
         # Call helper function directly instead of using Splunk search
         try:
             query_results = get_outliers_data(
@@ -297,6 +403,7 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
     def post_outliers_get_summary(self, request_info, **kwargs):
 
         describe = False
+        object_id_value = None  # Initialize at function scope
 
         # Retrieve from data
         try:
@@ -321,12 +428,22 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 500,
                     }
-                try:
-                    object_value = resp_dict["object"]
-                except Exception as e:
+                
+                # Support both object and object_id, prefer object_id if both provided
+                object_value = None
+                object_id_value = resp_dict.get("object_id")
+                object_param = resp_dict.get("object")
+                
+                if object_id_value:
+                    # object_id provided - will look up object value later
+                    object_value = None  # Will be resolved after service connection
+                elif object_param:
+                    # object provided
+                    object_value = object_param
+                else:
                     return {
                         "payload": {
-                            "response": "object is required",
+                            "response": "object or object_id is required",
                         },
                         "status": 500,
                     }
@@ -392,6 +509,48 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
             logger.error(json.dumps(response))
             return {"payload": response, "status": 500}
 
+        # If object_id was provided, look up the object value from KV store
+        if object_id_value and not object_value:
+            try:
+                # Try to get object from rules collection first (both collections should have the same object)
+                collection_rules_name = (
+                    f"kv_trackme_{component}_outliers_entity_rules_tenant_{tenant_id}"
+                )
+                collection_rule = service.kvstore[collection_rules_name]
+                
+                # Query by _key (object_id)
+                query_string = {"_key": object_id_value}
+                records = collection_rule.data.query(query=json.dumps(query_string))
+                
+                # Try rules collection first
+                if records and len(records) > 0:
+                    object_value = records[0].get("object")
+                
+                # If not found in rules collection, try data collection as fallback
+                if not object_value:
+                    collection_data_name = (
+                        f"kv_trackme_{component}_outliers_entity_data_tenant_{tenant_id}"
+                    )
+                    collection_data = service.kvstore[collection_data_name]
+                    records_data = collection_data.data.query(query=json.dumps(query_string))
+                    if records_data and len(records_data) > 0:
+                        object_value = records_data[0].get("object")
+                
+                if not object_value:
+                    return {
+                        "payload": {
+                            "response": f'object_id="{object_id_value}" not found in KV store',
+                        },
+                        "status": 500,
+                    }
+            except Exception as e:
+                response = {
+                    "action": "failure",
+                    "response": f'Failed to look up object from object_id, exception="{str(e)}"',
+                }
+                logger.error(json.dumps(response))
+                return {"payload": response, "status": 500}
+
         # Call both helper functions and merge results by model_id
         try:
             # Get rules
@@ -459,6 +618,7 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
     def post_outliers_get_models(self, request_info, **kwargs):
 
         describe = False
+        object_id_value = None  # Initialize at function scope
 
         # Retrieve from data
         try:
@@ -483,12 +643,22 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
                         },
                         "status": 500,
                     }
-                try:
-                    object_value = resp_dict["object"]
-                except Exception as e:
+                
+                # Support both object and object_id, prefer object_id if both provided
+                object_value = None
+                object_id_value = resp_dict.get("object_id")
+                object_param = resp_dict.get("object")
+                
+                if object_id_value:
+                    # object_id provided - will look up object value later
+                    object_value = None  # Will be resolved after service connection
+                elif object_param:
+                    # object provided
+                    object_value = object_param
+                else:
                     return {
                         "payload": {
-                            "response": "object is required",
+                            "response": "object or object_id is required",
                         },
                         "status": 500,
                     }
@@ -541,6 +711,48 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
         )
         logger.setLevel(loglevel)
 
+        # If object_id was provided, look up the object value from KV store
+        if object_id_value and not object_value:
+            try:
+                # Try to get object from rules collection first (both collections should have the same object)
+                collection_rules_name = (
+                    f"kv_trackme_{component}_outliers_entity_rules_tenant_{tenant_id}"
+                )
+                collection_rule = service.kvstore[collection_rules_name]
+                
+                # Query by _key (object_id)
+                query_string = {"_key": object_id_value}
+                records = collection_rule.data.query(query=json.dumps(query_string))
+                
+                # Try rules collection first
+                if records and len(records) > 0:
+                    object_value = records[0].get("object")
+                
+                # If not found in rules collection, try data collection as fallback
+                if not object_value:
+                    collection_data_name = (
+                        f"kv_trackme_{component}_outliers_entity_data_tenant_{tenant_id}"
+                    )
+                    collection_data = service.kvstore[collection_data_name]
+                    records_data = collection_data.data.query(query=json.dumps(query_string))
+                    if records_data and len(records_data) > 0:
+                        object_value = records_data[0].get("object")
+                
+                if not object_value:
+                    return {
+                        "payload": {
+                            "response": f'object_id="{object_id_value}" not found in KV store',
+                        },
+                        "status": 500,
+                    }
+            except Exception as e:
+                response = {
+                    "action": "failure",
+                    "response": f'Failed to look up object from object_id, exception="{str(e)}"',
+                }
+                logger.error(json.dumps(response))
+                return {"payload": response, "status": 500}
+
         # Define the SPL query
         kwargs_search = {
             "app": "trackme",
@@ -580,6 +792,7 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
     # render ML entity model
     def post_outliers_render_entity_model(self, request_info, **kwargs):
         describe = False
+        object_id_value = None  # Initialize at function scope
 
         logger.debug(f"Starting function post_outliers_render_entity_model")
 
@@ -608,12 +821,21 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
                         "status": 500,
                     }
 
-                try:
-                    object_value = resp_dict["object"]
-                except Exception as e:
+                # Support both object and object_id, prefer object_id if both provided
+                object_value = None
+                object_id_value = resp_dict.get("object_id")
+                object_param = resp_dict.get("object")
+                
+                if object_id_value:
+                    # object_id provided - will look up object value later
+                    object_value = None  # Will be resolved after service connection
+                elif object_param:
+                    # object provided
+                    object_value = object_param
+                else:
                     return {
                         "payload": {
-                            "response": "object is required",
+                            "response": "object or object_id is required",
                         },
                         "status": 500,
                     }
@@ -717,6 +939,48 @@ class TrackMeHandlerSplkOutliersEngineRead_v2(trackme_rest_handler.RESTHandler):
         )
         logger.setLevel(loglevel)
 
+        # If object_id was provided, look up the object value from KV store
+        if object_id_value and not object_value:
+            try:
+                # Try to get object from rules collection first (both collections should have the same object)
+                collection_rules_name_temp = (
+                    f"kv_trackme_{component}_outliers_entity_rules_tenant_{tenant_id}"
+                )
+                collection_rule_temp = service.kvstore[collection_rules_name_temp]
+                
+                # Query by _key (object_id)
+                query_string = {"_key": object_id_value}
+                records = collection_rule_temp.data.query(query=json.dumps(query_string))
+                
+                # Try rules collection first
+                if records and len(records) > 0:
+                    object_value = records[0].get("object")
+                
+                # If not found in rules collection, try data collection as fallback
+                if not object_value:
+                    collection_data_name = (
+                        f"kv_trackme_{component}_outliers_entity_data_tenant_{tenant_id}"
+                    )
+                    collection_data = service.kvstore[collection_data_name]
+                    records_data = collection_data.data.query(query=json.dumps(query_string))
+                    if records_data and len(records_data) > 0:
+                        object_value = records_data[0].get("object")
+                
+                if not object_value:
+                    return {
+                        "payload": {
+                            "response": f'object_id="{object_id_value}" not found in KV store',
+                        },
+                        "status": 500,
+                    }
+            except Exception as e:
+                response = {
+                    "action": "failure",
+                    "response": f'Failed to look up object from object_id, exception="{str(e)}"',
+                }
+                logger.error(json.dumps(response))
+                return {"payload": response, "status": 500}
+
         # start time
         start_time = time.time()
 
