@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -194,14 +194,30 @@ class TrackMeSplkFlxParse(StreamingCommand):
                             threshold_value = float(threshold_value)
                         except (TypeError, ValueError):
                             pass
-                        collection_records_dict[item.get("object_id")] = {
+                        # Get score, default to 100 if not present (for backward compatibility)
+                        score = item.get("score")
+                        if score is None:
+                            score = 100
+                        else:
+                            try:
+                                score = int(score)
+                            except (TypeError, ValueError):
+                                score = 100
+                        
+                        # Store thresholds keyed by object_id, then by metric_name to support multiple thresholds per entity
+                        object_id = item.get("object_id")
+                        metric_name = item.get("metric_name")
+                        if object_id not in collection_records_dict:
+                            collection_records_dict[object_id] = {}
+                        collection_records_dict[object_id][metric_name] = {
                             "_key": item.get("_key"),
-                            "metric_name": item.get("metric_name"),
+                            "metric_name": metric_name,
                             "mtime": float(item.get("mtime", 0)),
                             "operator": item.get("operator"),
                             "value": threshold_value,
                             "condition_true": int(item.get("condition_true", 0)),
                             "comment": item.get("comment"),
+                            "score": score,
                         }
                 skip_tracker += 5000
             else:
@@ -469,8 +485,8 @@ class TrackMeSplkFlxParse(StreamingCommand):
         # for thresholds, if defined we will initialize the base dict with the first entity result (all entities share the same threshold definition from the tracker point of view)
         thresholds_records_base_dict = {}
 
-        # thresholds list of keys to be added once we have iterated through the records
-        thresholds_records_keys_to_add = []
+        # thresholds dict mapping metric_name to list of entity keys that need this specific metric threshold
+        thresholds_records_keys_to_add = {}
 
         # disruption queue records to be added once we have iterated through the records
         disruption_queue_records_to_add = []
@@ -546,7 +562,8 @@ class TrackMeSplkFlxParse(StreamingCommand):
 
             try:
                 flx_tracker_name = record.get("tracker_name")
-                flx_record["tracker_name"] = flx_tracker_name
+                # Don't store tracker_name directly here - will be stored as JSON array later for concurrent tracker support
+                # flx_record["tracker_name"] = flx_tracker_name
             except Exception as e:
                 flx_tracker_name = None
 
@@ -595,7 +612,11 @@ class TrackMeSplkFlxParse(StreamingCommand):
 
             try:
                 flx_status = record.get("status")
-                flx_record["status"] = flx_status
+                # Convert to int if possible
+                try:
+                    flx_status = int(flx_status)
+                except (ValueError, TypeError):
+                    pass
             except Exception as e:
                 flx_status = None
             if not flx_status:
@@ -988,6 +1009,57 @@ class TrackMeSplkFlxParse(StreamingCommand):
                     )
                     flx_disruption_min_time_sec = None
 
+            ###################
+            # max_sec_inactive
+            ###################
+
+            try:
+                flx_max_sec_inactive = record.get("max_sec_inactive", None)
+            except Exception as e:
+                flx_max_sec_inactive = None
+
+            if flx_max_sec_inactive is not None:
+                try:
+                    # Handle tracker-keyed JSON format (from concurrent trackers)
+                    if isinstance(flx_max_sec_inactive, str):
+                        try:
+                            parsed = json.loads(flx_max_sec_inactive)
+                            if isinstance(parsed, dict):
+                                # Tracker-keyed format: extract minimum value (excluding 0)
+                                non_zero_values = [int(float(v)) for v in parsed.values() if int(float(v)) > 0]
+                                if non_zero_values:
+                                    flx_max_sec_inactive = min(non_zero_values)
+                                else:
+                                    # All values are 0, use 0 (disabled)
+                                    flx_max_sec_inactive = 0
+                            else:
+                                # Not a dict, treat as simple numeric string
+                                flx_max_sec_inactive = int(float(flx_max_sec_inactive))
+                        except (json.JSONDecodeError, TypeError, ValueError):
+                            # Not JSON, treat as simple numeric string
+                            flx_max_sec_inactive = int(float(flx_max_sec_inactive))
+                    elif isinstance(flx_max_sec_inactive, dict):
+                        # Already a dict (tracker-keyed format)
+                        non_zero_values = [int(float(v)) for v in flx_max_sec_inactive.values() if int(float(v)) > 0]
+                        if non_zero_values:
+                            flx_max_sec_inactive = min(non_zero_values)
+                        else:
+                            flx_max_sec_inactive = 0
+                    else:
+                        # Simple numeric value
+                        flx_max_sec_inactive = int(flx_max_sec_inactive)
+                    
+                    if flx_max_sec_inactive < 0:
+                        logging.error(
+                            f'instance_id="{self.instance_id}", The field max_sec_inactive must be a positive integer or zero, value="{flx_max_sec_inactive}"'
+                        )
+                        flx_max_sec_inactive = None
+                except Exception as e:
+                    logging.error(
+                        f'instance_id="{self.instance_id}", The field max_sec_inactive must be a positive integer or zero, value="{flx_max_sec_inactive}", exception="{str(e)}"'
+                    )
+                    flx_max_sec_inactive = None
+
             # if simulation mode, add an informational message related to the disruption min time
             if self.context == "simulation" and "disruption_min_time_sec" in record:
                 if flx_disruption_min_time_sec is not None:
@@ -1221,16 +1293,42 @@ class TrackMeSplkFlxParse(StreamingCommand):
             if self.context == "live":
 
                 if flx_default_threshold and (flx_metrics or flx_metrics_list):
-                    # check if this entity has a threshold already
-                    if flx_sha256 in thresholds_collection:
-                        pass
-                    else:
-
-                        # Process each threshold in the list
-                        for threshold in flx_default_threshold:
+                    # Process each threshold in the list
+                    for threshold in flx_default_threshold:
+                        metric_name = threshold.get("metric_name")
+                        
+                        # Skip if metric_name is missing or empty
+                        if not metric_name:
+                            logging.warning(
+                                f'instance_id="{self.instance_id}", skipping threshold with missing or empty metric_name for entity="{flx_sha256}", threshold="{json.dumps(threshold)}"'
+                            )
+                            continue
+                        
+                        # Check if this specific threshold (entity + metric_name) already exists
+                        threshold_exists = False
+                        if flx_sha256 in thresholds_collection:
+                            entity_thresholds = thresholds_collection[flx_sha256]
+                            # thresholds_collection is now nested: dict[object_id][metric_name]
+                            # Check if it's the new nested format (dict of dicts) or old format (single dict)
+                            if isinstance(entity_thresholds, dict):
+                                # New format: nested dict[object_id][metric_name] - check if metric_name is a key
+                                if metric_name and metric_name in entity_thresholds:
+                                    threshold_exists = True
+                                    logging.debug(
+                                        f'instance_id="{self.instance_id}", found existing threshold for entity="{flx_sha256}", metric_name="{metric_name}", skipping addition of default threshold'
+                                    )
+                                # Old format: single threshold dict with metric_name as a value field
+                                # Only check old format if metric_name is not None to avoid None == None false matches
+                                elif metric_name is not None and entity_thresholds.get("metric_name") == metric_name:
+                                    threshold_exists = True
+                                    logging.debug(
+                                        f'instance_id="{self.instance_id}", found existing threshold for entity="{flx_sha256}", metric_name="{metric_name}" (old format), skipping addition of default threshold'
+                                    )
+                        
+                        if not threshold_exists:
                             data = {
                                 "tenant_id": self.tenant_id,
-                                "metric_name": threshold.get("metric_name"),
+                                "metric_name": metric_name,
                                 "value": threshold.get("value"),
                                 "operator": threshold.get("operator"),
                                 "condition_true": threshold.get("condition_true"),
@@ -1242,15 +1340,18 @@ class TrackMeSplkFlxParse(StreamingCommand):
 
                             # add to the list of records to be added if this particular threshold is not already in the list
                             if (
-                                threshold.get("metric_name")
+                                metric_name
                                 not in thresholds_records_base_dict
                             ):
                                 thresholds_records_base_dict[
-                                    threshold.get("metric_name")
+                                    metric_name
                                 ] = data
 
-                            # add to the list of keys to be added
-                            thresholds_records_keys_to_add.append(flx_sha256)
+                            # add to the list of keys for this specific metric
+                            if metric_name not in thresholds_records_keys_to_add:
+                                thresholds_records_keys_to_add[metric_name] = []
+                            if flx_sha256 not in thresholds_records_keys_to_add[metric_name]:
+                                thresholds_records_keys_to_add[metric_name].append(flx_sha256)
 
             ##################################
             # End Processing default threshold
@@ -1260,21 +1361,10 @@ class TrackMeSplkFlxParse(StreamingCommand):
             # Start Processing disruption min time
             ####################################
 
-            if self.context == "live" and flx_disruption_min_time_sec is not None:
-
-                # check if this entity has a disruption record already
-                if flx_sha256 not in disruption_queue_collection_keys:
-                    # create a new disruption record
-                    disruption_record = {
-                        "_key": flx_sha256,
-                        "disruption_min_time_sec": flx_disruption_min_time_sec,
-                        "disruption_start_epoch": 0,
-                        "object_state": "green",
-                        "mtime": time.time(),
-                    }
-
-                    # add to the list of records to be added
-                    disruption_queue_records_to_add.append(disruption_record)
+            # Note: disruption_min_time_sec is now stored as tracker-keyed JSON in the main FLX collection
+            # The disruption queue record will be updated in trackmedecisionmaker.py using the aggregated maximum value
+            # We no longer create disruption queue records here to avoid conflicts with concurrent trackers
+            # The disruption queue will be managed in trackmedecisionmaker.py after aggregation
 
             ##################################
             # End Processing disruption min time
@@ -1296,8 +1386,79 @@ class TrackMeSplkFlxParse(StreamingCommand):
             # finally
             yield_record[flx_object] = flx_record
 
-            # add metrics
-            flx_record["metrics"] = flx_metrics
+            # Normalize tracker_name for consistent storage
+            normalized_tracker_name = None
+            if flx_tracker_name:
+                normalized_tracker_name = normalize_flx_tracker_name(self.tenant_id, flx_tracker_name)
+
+            # Store tracker_name as JSON array for concurrent tracker support
+            # Store metrics, status_description, and status_description_short as JSON objects keyed by tracker_name
+            # for concurrent tracker support
+            if normalized_tracker_name:
+                # Store tracker_name as JSON array (will be merged in trackmepersistentfields)
+                flx_record["tracker_name"] = json.dumps([normalized_tracker_name])
+                # Convert metrics to tracker-keyed JSON object
+                if isinstance(flx_metrics, dict):
+                    metrics_by_tracker = {normalized_tracker_name: flx_metrics}
+                    flx_record["metrics"] = json.dumps(metrics_by_tracker)
+                else:
+                    # If metrics is not a dict, store empty dict for this tracker
+                    metrics_by_tracker = {normalized_tracker_name: {}}
+                    flx_record["metrics"] = json.dumps(metrics_by_tracker)
+                
+                # Convert status_description to tracker-keyed JSON object
+                # Only create entry if we have actual content (not empty/None)
+                if flx_status_description:
+                    status_description_by_tracker = {normalized_tracker_name: flx_status_description}
+                    flx_record["status_description"] = json.dumps(status_description_by_tracker)
+                # If empty, don't create the field (will be preserved from existing record if present)
+                
+                # Convert status_description_short to tracker-keyed JSON object
+                # Only create entry if we have actual content (not empty/None)
+                if flx_status_description_short:
+                    status_description_short_by_tracker = {normalized_tracker_name: flx_status_description_short}
+                    flx_record["status_description_short"] = json.dumps(status_description_short_by_tracker)
+                # If empty, don't create the field (will be preserved from existing record if present)
+                
+                # Convert object_description to tracker-keyed JSON object
+                # Only create entry if we have actual content (not empty/None)
+                if flx_object_description:
+                    object_description_by_tracker = {normalized_tracker_name: flx_object_description}
+                    flx_record["object_description"] = json.dumps(object_description_by_tracker)
+                # If empty, don't create the field (will be preserved from existing record if present)
+                
+                # Convert disruption_min_time_sec to tracker-keyed JSON object
+                # Only create entry if we have actual content (not empty/None)
+                if flx_disruption_min_time_sec is not None:
+                    disruption_min_time_by_tracker = {normalized_tracker_name: flx_disruption_min_time_sec}
+                    flx_record["disruption_min_time_sec"] = json.dumps(disruption_min_time_by_tracker)
+                # If empty, don't create the field (will be preserved from existing record if present)
+                
+                # Convert max_sec_inactive to tracker-keyed JSON object
+                # Only create entry if we have actual content (not empty/None)
+                if flx_max_sec_inactive is not None:
+                    max_sec_inactive_by_tracker = {normalized_tracker_name: flx_max_sec_inactive}
+                    flx_record["max_sec_inactive"] = json.dumps(max_sec_inactive_by_tracker)
+                # If empty, don't create the field (will be preserved from existing record if present)
+                
+                # Convert status to tracker-keyed JSON object
+                # Status is mandatory, so always create entry
+                if flx_status is not None:
+                    status_by_tracker = {normalized_tracker_name: flx_status}
+                    flx_record["status"] = json.dumps(status_by_tracker)
+            else:
+                # No tracker name, store as-is (backward compatibility)
+                flx_record["metrics"] = flx_metrics
+                flx_record["status_description"] = flx_status_description
+                flx_record["status_description_short"] = flx_status_description_short
+                flx_record["object_description"] = flx_object_description
+                # Store status as-is for backward compatibility (no tracker name)
+                flx_record["status"] = flx_status
+                # Store tracker_name as-is for backward compatibility (not as JSON array)
+                if flx_tracker_name:
+                    flx_record["tracker_name"] = flx_tracker_name
+                # max_sec_inactive stored as-is for backward compatibility (no tracker name)
+                # disruption_min_time_sec stored as-is for backward compatibility (no tracker name)
 
             # add outliers_metrics
             flx_record["outliers_metrics"] = flx_outliers_metrics
@@ -1306,9 +1467,7 @@ class TrackMeSplkFlxParse(StreamingCommand):
             flx_extra_attributes = record.get("extra_attributes", None)
             flx_record["extra_attributes"] = flx_extra_attributes
 
-            # max_sec_inactive, this is optional
-            flx_max_sec_inactive = record.get("max_sec_inactive", None)
-            flx_record["max_sec_inactive"] = flx_max_sec_inactive
+            # max_sec_inactive is already assigned earlier (before tracker-keyed JSON conversion)
 
             # if in simulation, add an informational message related to the metrics management
             if self.context == "simulation":
@@ -1323,22 +1482,27 @@ class TrackMeSplkFlxParse(StreamingCommand):
                 flx_record["outliers_metrics_message"] = flx_outliers_metrics_parsed_msg
 
                 # yield
+                # Use the tracker-keyed JSON objects from flx_record
                 yield_record = {
                     "group": flx_group,
                     "object": flx_object,
                     "alias": flx_alias,
                     "object_category": "splk-flx",
-                    "object_description": flx_object_description,
                     "status": flx_status,
-                    "status_description": flx_status_description,
-                    "status_description_short": flx_status_description_short,
-                    "metrics": flx_metrics,
+                    "metrics": flx_record.get("metrics", flx_metrics),
                     "metrics_message": flx_metrics_parsed_msg,
                     "outliers_metrics": flx_outliers_metrics,
                     "outliers_metrics_message": flx_outliers_metrics_parsed_msg,
                     "extra_attributes": flx_extra_attributes,
-                    "max_sec_inactive": flx_max_sec_inactive,
+                    "max_sec_inactive": flx_record.get("max_sec_inactive", flx_max_sec_inactive),
                 }
+                # Only include status_description, status_description_short, and object_description if they have content
+                if "status_description" in flx_record:
+                    yield_record["status_description"] = flx_record["status_description"]
+                if "status_description_short" in flx_record:
+                    yield_record["status_description_short"] = flx_record["status_description_short"]
+                if "object_description" in flx_record:
+                    yield_record["object_description"] = flx_record["object_description"]
                 
                 # conditionally include _time and _raw
                 if not self.remove_time:
@@ -1362,21 +1526,26 @@ class TrackMeSplkFlxParse(StreamingCommand):
 
             else:
                 # yield
+                # Use the tracker-keyed JSON objects from flx_record
                 yield_record = {
                     "group": flx_group,
                     "object": flx_object,
                     "alias": flx_alias,
                     "object_category": "splk-flx",
-                    "object_description": flx_object_description,
                     "status": flx_status,
-                    "status_description": flx_status_description,
-                    "status_description_short": flx_status_description_short,
-                    "metrics": flx_metrics,
+                    "metrics": flx_record.get("metrics", flx_metrics),
                     "outliers_metrics": flx_outliers_metrics,
                     "extra_attributes": flx_extra_attributes,
-                    "max_sec_inactive": flx_max_sec_inactive,
+                    "max_sec_inactive": flx_record.get("max_sec_inactive", flx_max_sec_inactive),
                     "flx_type": self.flx_type,
                 }
+                # Only include status_description, status_description_short, and object_description if they have content
+                if "status_description" in flx_record:
+                    yield_record["status_description"] = flx_record["status_description"]
+                if "status_description_short" in flx_record:
+                    yield_record["status_description_short"] = flx_record["status_description_short"]
+                if "object_description" in flx_record:
+                    yield_record["object_description"] = flx_record["object_description"]
                 
                 # conditionally include _time and _raw
                 if not self.remove_time:
@@ -1420,8 +1589,12 @@ class TrackMeSplkFlxParse(StreamingCommand):
 
             # Iterate through each metric name in the base dict
             for metric_name, data in thresholds_records_base_dict.items():
-                # add keys_list to the data (turn the list into a CSV string)
-                data["keys_list"] = ",".join(thresholds_records_keys_to_add)
+                # add keys_list to the data (only include keys for this specific metric)
+                if metric_name in thresholds_records_keys_to_add:
+                    data["keys_list"] = ",".join(thresholds_records_keys_to_add[metric_name])
+                else:
+                    # Skip this metric if no entities need it
+                    continue
 
                 try:
                     response = session.post(
@@ -1432,7 +1605,7 @@ class TrackMeSplkFlxParse(StreamingCommand):
                     )
                     response.raise_for_status()
                     logging.info(
-                        f'tenant_id="{self.tenant_id}", default threshold added successfully for metric {metric_name} and {len(thresholds_records_keys_to_add)} entities, http_status="{response.status_code}", data="{json.dumps(data, indent=2)}"'
+                        f'tenant_id="{self.tenant_id}", default threshold added successfully for metric {metric_name} and {len(thresholds_records_keys_to_add[metric_name])} entities, http_status="{response.status_code}", data="{json.dumps(data, indent=2)}"'
                     )
                 except Exception as e:
                     logging.error(
