@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -72,6 +72,8 @@ from trackme_libs import (
     trackme_register_tenant_object_summary,
     run_splunk_search,
     trackme_handler_events,
+    trackme_idx_for_tenant,
+    trackme_gen_state,
 )
 
 # import trackme libs utils
@@ -80,6 +82,8 @@ from trackme_libs_utils import remove_leading_spaces, decode_unicode
 # import trackme libs croniter
 from trackme_libs_croniter import cron_to_seconds
 
+# import trackme libs scoring
+from trackme_libs_scoring import trackme_scoring_gen_metrics
 
 @Configuration(distributed=False)
 class SplkOutliersTracker(GeneratingCommand):
@@ -188,6 +192,13 @@ class SplkOutliersTracker(GeneratingCommand):
             f'vtenant_component_info="{json.dumps(vtenant_component_info, indent=2)}"'
         )
 
+        # Get the tenant indexes
+        tenant_indexes = trackme_idx_for_tenant(
+            self._metadata.searchinfo.session_key,
+            self._metadata.searchinfo.splunkd_uri,
+            self.tenant_id,
+        )        
+
         # check schema version migration state
         try:
             schema_version = int(vtenant_component_info["schema_version"])
@@ -259,6 +270,9 @@ class SplkOutliersTracker(GeneratingCommand):
             # counter
             count = 0
 
+            # scoring metrics records
+            scoring_metrics_records = []            
+
             # Get the session key
             session_key = self._metadata.searchinfo.session_key
 
@@ -514,6 +528,12 @@ class SplkOutliersTracker(GeneratingCommand):
                                                 f'kpi_metric_name="{kpi_metric_name}"'
                                             )
 
+                                            # retrieve the score from the model configuration
+                                            try:
+                                                score = int(model_config.get("score", 36))
+                                            except (ValueError, TypeError):
+                                                score = 36
+
                                             # Set the initial state for that model
                                             isOutlier = 0
                                             isOutlierReason = "None"
@@ -695,6 +715,18 @@ class SplkOutliersTracker(GeneratingCommand):
                                                                     ) * 100
                                                                     isOutlierReason = f'Outliers ML for kpi="{kpi_metric_name}", model_id="{model_id}", LowerBound="{round(float(LowerBound), 3)}" breached with kpi_metric_value="{round(float(kpi_metric_value), 3)}" at time="{time_outlier}", pct_decrease="{round(float(pct_decrease), 2)}"'
 
+                                                                    # add to scoring metrics records
+                                                                    scoring_metrics_records.append(
+                                                                        {
+                                                                            "tenant_id": self.tenant_id,
+                                                                            "object_id": key,
+                                                                            "object": object_value,
+                                                                            "object_category": self.component,
+                                                                            "score_source": f"lowerbound_outlier|model_id={model_id}",
+                                                                            "metrics_event": {"score": score, "pct_decrease": round(float(pct_decrease), 2)},
+                                                                        }
+                                                                    )
+
                                                             elif int(
                                                                 alert_upper_breached
                                                             ) == 1 and float(
@@ -729,6 +761,18 @@ class SplkOutliersTracker(GeneratingCommand):
                                                                     ) * 100
                                                                     isOutlierReason = f'Outliers ML for kpi="{kpi_metric_name}", model_id="{model_id}", UpperBound="{round(float(UpperBound), 3)}" breached with kpi_metric_value="{round(float(kpi_metric_value), 3)}" at time="{time_outlier}", pct_increase="{round(float(pct_increase), 2)}"'
 
+                                                                    # add to scoring metrics records
+                                                                    scoring_metrics_records.append(
+                                                                        {
+                                                                            "tenant_id": self.tenant_id,
+                                                                            "object_id": key,
+                                                                            "object": object_value,
+                                                                            "object_category": self.component,
+                                                                            "score_source": f"upperbound_outlier|model_id={model_id}",
+                                                                            "metrics_event": {"score": score, "pct_increase": round(float(pct_increase), 2)},
+                                                                        }
+                                                                    )
+
                                                             else:
                                                                 isOutlier = 0
                                                                 isOutlierReason = "No outliers anomalies were detected"
@@ -957,6 +1001,36 @@ class SplkOutliersTracker(GeneratingCommand):
                             f'tenant_id="{self.tenant_id}", component=f"splk-{self.component}", could not send notification event, exception="{e}"'
                         )
 
+                    # call the scoring gen metrics function
+                    scoring_metrics_gen_start = time.time()
+                    try:
+                        scoring_metrics = trackme_scoring_gen_metrics(
+                            self.tenant_id,
+                            tenant_indexes.get("trackme_metric_idx"),
+                            scoring_metrics_records,
+                        )
+                        logging.info(
+                            f'context="scoring_gen_metrics", tenant_id="{self.tenant_id}", function trackme_scoring_gen_metrics success {scoring_metrics}, run_time={round(time.time()-scoring_metrics_gen_start, 3)}, no_entities={len(scoring_metrics_records)}'
+                        )
+                    except Exception as e:
+                        logging.error(
+                            f'context="scoring_gen_metrics", tenant_id="{self.tenant_id}", function trackme_scoring_gen_metrics failed with exception {str(e)}'
+                        )
+
+                    # also generate events for the score
+                    for score_event in scoring_metrics_records:
+                        try:
+                            trackme_gen_state(
+                                index=tenant_indexes.get("trackme_summary_idx"),
+                                sourcetype="trackme:score",
+                                source=f"trackme_{self.component}_outliers_mlmonitor_tracker_tenant_{self.tenant_id}",
+                                event=score_event,
+                            )
+                        except Exception as e:
+                            logging.error(
+                                f'tenant_id="{self.tenant_id}", component="{self.component}", failed to generate score state event, exception="{str(e)}"'
+                            )
+
                 else:
                     logging.info(
                         f'tenant_id="{self.tenant_id}" outliers tracker job successfully executed but there were no entities to be tracked at this time, status="success", run_time="{round(time.time() - start, 3)}", report="{str(report_name)}", entities_count="{str(count)}"'
