@@ -2,7 +2,7 @@
 # coding=utf-8
 
 __author__ = "TrackMe Limited"
-__copyright__ = "Copyright 2023-2025, TrackMe Limited, U.K."
+__copyright__ = "Copyright 2022-2026, TrackMe Limited, U.K."
 __credits__ = "TrackMe Limited, U.K."
 __license__ = "TrackMe Limited, all rights reserved"
 __version__ = "0.1.0"
@@ -102,7 +102,7 @@ def post_bulk_edit(
             + "mode=\"post\" body=\"{'tenant_id':'mytenant', "
             + "'json_data':[{'keyid':'b55658d1fc032ea3e1ecfc9eb60ad070','object':'netscreen:netscreen:firewall',"
             + "'alias':'netscreen:netscreen:firewall','priority':'high','monitored_state':'enabled',"
-            + "'data_override_lagging_class':'false','data_lag_alert_kpis':'all_kpis','data_max_lag_allowed':'3600',"
+            + "'data_override_lagging_class':'false','data_max_lag_allowed':'3600',"
             + "'data_max_delay_allowed':'3600'}]}\"",
             "options": [
                 {
